#!/bin/sh
set -v
#
#
#  Access Point config 
#
# get list of configured guest wireless networks
# Guest24=`nvram get wl0_vifs`
# Guest5=`nvram get wl1_vifs`
#
# generate mac address from lan address by making last part :FE
my_mac_addr=`nvram get lan_hwaddr | awk '{FS = ":" }{print $1":"$2":"$3":"$4":"$5":FE"}'`
#
logger -t $0 "Configure vlan3 and br1 - Guest MAC used $my_mac_addr"
#
# define vlan3 (Guest network over wired link)
#  use eth0 but with a different MAC address from eth0 (vlan1 - br0)
#  (router dhcp server gets confused with duplicate MAC address)
#  (when wl0.1 is added,  MAC address becomes that of wl0.1)
vconfig add eth0 3
ip link set dev vlan3 down
ip link set dev vlan3 address $my_mac_addr
#
# WAN port 0 will be link to main router running tagged vlans
#      LAN ports 1 2 are on guest network (close to WAN port)
#      LAN ports 3 4 are on private network (need one on private network for firmware updates)
#
robocfg vlan 1 ports "0t 3 4 8t" 
robocfg vlan 2 ports "8u"
robocfg vlan 3 ports "0t 1 2 8t"
robocfg port 0 state enabled tag 3 
# 
# robocfg show
#
#
# define br1 (Guest network)
#
ip link set dev br1 down
brctl delbr br1
brctl addbr br1
brctl addif br1 vlan3
#  Spanning Tree Protocol (STP) can cause problems with VLANs
brctl stp br1 off
brctl stp br0 off
# attempt to move wireless guest fails #
# brctl delif br0 wl0.1
# brctl addif br1 wl0.1
#
# brctl show
#
# now br1 and vlan3 has everything defined, start them
#
ip link set dev vlan3 up
ip link set dev br1 up
# wait for vlan3 to come up
sleep 15
#
#  get an ip address on the guest network
#
if [ -f /var/run/udhcpc_br1.pid ]
  then
    kill -SIGUSR1 `cat /var/run/udhcpc_br1.pid`
  else
    my_temp_name=`nvram get computer_name`
#          truncate name to 18 chars and eliminate any chars like blanks that should not be in host name
    my_computer_name_p1=`expr substr "$my_temp_name" 1 18 | sed -e 's/[^A-Z^a-z^0-9^-]\+//g'`
    my_computer_name_p2=`echo $my_mac_addr  | awk '{FS = ":" }{print $1$2$3$4$5$6}'`
    my_computer_name="$my_computer_name_p1-$my_computer_name_p2"
#            -t 100 trys at 3 seconds each means 5 minutes
    udhcpc -i br1 -p /var/run/udhcpc_br1.pid -t 100 -b -H "$my_computer_name" -s "/jffs/scripts/udhcpc_brX"
fi
#

